###
##
# Plone-Keyword-Manager
#
# Copyright (C) 2003 Maik Jablonski (maik.jablonski@uni-bielefeld.de)
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#
# Uses Levenshtein-C-Wrapper for Python if installed,
# if not, use python-difflib. Levenshtein is recommended,
# because it will speed things up ~ 10 times.
#
# More info about Levenshtein on:
# http://trific.ath.cx/resources/python/levenshtein/
##
###


from Products.CMFCore.DirectoryView import registerDirectory
    
global cmf_keyword_manager_globals
cmf_keyword_manager_globals=globals()

def get_scored_matches(self, word, possibilities, num, score):
    """ Take a word,
        compare it to a list of possibilities,
        return max. num matches > score).
    """
    try:
        import Levenshtein

        res = []
        
        # Search for all similar terms in possibilities
        for item in possibilities:
            lscore = Levenshtein.ratio(word, item)
            if lscore > score:
                res.append((item,lscore))

        # Sort by score (high scores on top of list)
        res.sort(lambda x,y: -cmp(x[1],y[1]))

        # Return first n terms without scores
        return [item[0] for item in res[:num]]

    except ImportError:
        import difflib
        return difflib.get_close_matches(word, possibilities, num, score)
    
methods = {'get_scored_matches': get_scored_matches,}

def initialize(context):
    registerDirectory('skins', cmf_keyword_manager_globals)
